@@ -18,7 +18,7 @@ list_mgmt <- function(path, query, token) {
 #' @include utils.R
 get_mgmt <- function(path, token) {
     data_list <- get_response(type = "mgmt", path = path, token = token)
-    data_list <- rename_mgmt(data_list)
+    data_list <- ls_mgmt(data_list)
     data_list <- convert_datatypes(data_list)
     data_list$created <- as.POSIXct(strptime(data_list$created, format = "%Y-%m-%dT%H:%M:%OS", tz = "GMT"))
     data_list$updated <- as.POSIXct(strptime(data_list$updated, format = "%Y-%m-%dT%H:%M:%OS", tz = "GMT"))
